Index: app_queue.c
===================================================================
--- app_queue.c	(revision 171829)
+++ app_queue.c	(arbetskopia)
@@ -146,6 +146,7 @@
 #define	RES_OUTOFMEMORY	(-2)		/*!< Out of memory */
 #define	RES_NOSUCHQUEUE	(-3)		/*!< No such queue */
 #define RES_NOT_DYNAMIC (-4)		/*!< Member is not dynamic */
+#define RES_REALTIME_FAILED (-5)		/*!< Member is not dynamic */
 
 static char *app = "Queue";
 
@@ -525,6 +526,7 @@
 
 static void copy_rules(struct queue_ent *qe, const char *rulename);
 static void update_qe_rule(struct queue_ent *qe);
+static int remove_realtime_queue_member(struct member *mem, const char *queue_name);
 static void update_realtime_members(struct call_queue *q);
 static int set_member_paused(const char *queuename, const char *interface, const char *reason, int paused);
 
@@ -1651,6 +1653,27 @@
 	return ret;
 }
 
+/*! \brief Remove a queue member from realtime queue_members
+ */
+static int remove_realtime_queue_member(struct member *mem, const char *queue_name)
+{
+	struct ast_variable *var;
+	int ret = -1;
+
+	if (!(var = ast_load_realtime("queue_members", "interface", mem->interface, "queue_name", queue_name, NULL))) 
+		return ret;
+	while (var) {
+		if (!strcmp(var->name, "uniqueid"))
+			break;
+		var = var->next;
+	}
+	if (var && !ast_strlen_zero(var->value)) {
+		if ((ast_destroy_realtime("queue_members", "uniqueid", var->value)) > -1)
+			ret = 0;
+	}
+	return ret;
+}
+
 static void update_realtime_members(struct call_queue *q)
 {
 	struct ast_config *member_config = NULL;
@@ -4012,6 +4035,7 @@
  * \retval RES_NOSUCHQUEUE queue does not exist
  * \retval RES_OKAY removed member from queue
  * \retval RES_EXISTS queue exists but no members
+ * \retval RES_REALTIME_FAILED updating realtime tables failed
 */
 static int remove_from_queue(const char *queuename, const char *interface)
 {
@@ -4027,7 +4051,16 @@
 		ao2_lock(q);
 		if ((mem = ao2_find(q->members, &tmpmem, OBJ_POINTER))) {
 			/* XXX future changes should beware of this assumption!! */
-			if (!mem->dynamic) {
+			if (mem->realtime) {
+				if(remove_realtime_queue_member(mem, queuename) == -1) {
+					ao2_ref(mem, -1);
+					ao2_unlock(q);
+					queue_unref(q);
+					ao2_unlock(queues);
+					return RES_REALTIME_FAILED;
+				}
+			}
+			else if (!mem->dynamic) {
 				ao2_ref(mem, -1);
 				ao2_unlock(q);
 				queue_unref(q);
@@ -4476,6 +4509,11 @@
 		pbx_builtin_setvar_helper(chan, "RQMSTATUS", "NOTDYNAMIC");
 		res = 0;
 		break;
+	case RES_REALTIME_FAILED:
+		ast_log(LOG_WARNING, "Unable to remove interface from queue '%s': Realtime update failed\n", args.queuename);
+		pbx_builtin_setvar_helper(chan, "RQMSTATUS", "REALTIMEFAILED");
+		res = 0;
+		break;
 	}
 
 	return res;
@@ -6014,6 +6052,9 @@
 	case RES_NOT_DYNAMIC:
 		astman_send_error(s, m, "Member not dynamic");
 		break;
+	case RES_REALTIME_FAILED:
+		astman_send_error(s, m, "Realtime update failed");
+		break;
 	}
 
 	return 0;
